@@ -31,9 +31,11 @@ dropNullsOrEmpty <- function(x) {
 
 
 # quickly clean a string
-#' @importFrom stringi stri_trans_general stri_replace_all_regex
+#' @importFrom stringi stri_trans_general stri_trans_tolower stri_replace_all_regex
 clean_string <- function(str) {
   str <- stri_trans_general(str = str, id = "Latin-ASCII")
+  str <- stri_trans_tolower(str)
+  str <- make.unique(str)
   str <- stri_replace_all_regex(str = str, pattern = "[^a-zA-Z0-9_]+", replacement = "_")
   return(str)
 }
@@ -247,14 +249,6 @@ col2Hex <- function(col) {
 }
 
 
-get_brewer_pal <- function(name) {
-  bpi <- RColorBrewer::brewer.pal.info
-  maxn <- bpi[rownames(bpi) %in% name, ]
-  maxn <- maxn$maxcolors
-  brewer.pal(n = maxn, name = name)
-}
-
-
 linear_gradient <- function(cols) {
   x <- round(seq(from = 0, to = 100, length.out = length(cols)+1))
   ind <- c(1, rep(seq_along(x)[-c(1, length(x))], each = 2), length(x))
